% rotmat2euler
% Computes the rotation matrix given Euler angles in the Tait-Bryan format
% for rotations about the body axes X, Y, Z (intrinsic rotations).
% See matrix R below, where
% (thx, thy, thz) = (roll-phi, pitch-theta, yaw-psi) 
%                 = rotations about (X, Y, Z)
%
%     |   cos(thz)*cos(thy)     cos(thz)*sin(thy)*sin(thx)-sin(thz)*cos(thx)    cos(thz)*sin(thy)*cos(thx)+sin(thz)*sin(thx) |
% R = |   sin(thz)*cos(thy)     sin(thz)*sin(thy)*sin(thx)+cos(thz)*cos(thx)    sin(thz)*sin(thy)*cos(thx)-cos(thz)*sin(thx) |
%     |  -sin(thy)                       cos(thy)*sin(thx)                               cos(thy)*cos(thx)                   |
%
% Miguel Torres-Torriti (c) XI.2011
%
% Remarks:
% Note that rotmat2euler can be applied to any rotation matrix, but the 
% result will be the rotation angles about the body axes in order X, Y, Z 
% (intrinsic rotation), in the Tait-Bryan format.
% If another convention of Euler angles is used, the procedure should be
% adapted accordingly.
%
% example: R = rotxyz([thx,thy,thz]) 
%          R = rotxyz([thx; thy; thz])
%          R = rotxyz([pi/4;pi/3;-pi/2])
%
function rm=rotxyz(theta)
thx = theta(1);
thy = theta(2);
thz = theta(3);
cthx = cos(thx);
sthx = sin(thx);
cthy = cos(thy);
sthy = sin(thy);
cthz = cos(thz);
sthz = sin(thz);

rm = [...
cthz*cthy cthz*sthy*sthx-sthz*cthx cthz*sthy*cthx+sthz*sthx;...
sthz*cthy sthz*sthy*sthx+cthz*cthx sthz*sthy*cthx-cthz*sthx;...
-sthy cthy*sthx cthy*cthx];

%cos(thz)*cos(thy)	cos(thz)*sin(thy)*sin(thx)-sin(thz)*cos(thx)	cos(thz)*sin(thy)*cos(thx)+sin(thz)*sin(thx)
%sin(thz)*cos(thy)	sin(thz)*sin(thy)*sin(thx)+cos(thz)*cos(thx)	sin(thz)*sin(thy)*cos(thx)-cos(thz)*sin(thx)
%-sin(thy)	cos(thy)*sin(thx)	cos(thy)*cos(thx)